# frozen_string_literal: true

require "colorize"
require "helpers"

class GameTemplate
  def initialize(game, remote = "")
    @game = game
    @remote = remote
  end

  def run(install_path)
    exec(@game.launch(install_path))
  end

  def install(install_path, steam_login)
    if @game.app_id.nil?
      @game.install_server(install_path)
    else
      install_steam_server(install_path, steam_login)
    end
    @game.post_install(install_path) if defined? @game.post_install
    create_unit_file(install_path)
  end

  private

  def install_steam_server(install_path, steam_login)
    abort("STEAMCMD does not appear to be installed! Aborting...".red) if `which steamcmd`.empty?
    system("$(which steamcmd) #{steam_login} +quit")
    system("$(which steamcmd) #{steam_login} +force_install_dir #{install_path} +app_update #{@game.app_id} validate +quit")
  end

  def create_unit_file(install_path)
    file_path = "/tmp/#{@game.name}.service"
    `touch #{file_path}`
    `echo "#{unit_file_contents(install_path)}" >> #{file_path}`
    system("mv -f #{"/tmp/#{@game.name}.service"} /etc/systemd/system/#{@game.name}.service")
  end

  def unit_file_contents(install_path)
    "[Unit]
    After=network.target
    Description=Daemon for #{@game.name} dedicated server
    [Install]
    WantedBy=default.target
    [Service]
    Type=simple
    ExecStart=#{`which gsd-cli`.strip()} run #{@game.name} --path #{install_path}"
  end
end
